package com.sun.corba.se.impl.protocol;

import com.sun.corba.se.spi.oa.ObjectAdapterFactory;
import com.sun.corba.se.spi.protocol.CorbaServerRequestDispatcher;
import com.sun.corba.se.spi.protocol.LocalClientRequestDispatcherFactory;
import com.sun.corba.se.pept.protocol.ClientRequestDispatcher;
import java.util.HashMap;
import java.util.Collections;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import com.sun.corba.se.impl.orbutil.DenseIntMapImpl;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.protocol.RequestDispatcherRegistry;

public class RequestDispatcherRegistryImpl implements RequestDispatcherRegistry
{
    private ORB orb;
    protected int defaultId;
    private DenseIntMapImpl SDRegistry;
    private DenseIntMapImpl CSRegistry;
    private DenseIntMapImpl OAFRegistry;
    private DenseIntMapImpl LCSFRegistry;
    private Set objectAdapterFactories;
    private Set objectAdapterFactoriesView;
    private Map stringToServerSubcontract;
    
    public RequestDispatcherRegistryImpl(ORB orb, int defaultId) {
        this.orb = orb;
        this.defaultId = defaultId;
        this.SDRegistry = new DenseIntMapImpl();
        this.CSRegistry = new DenseIntMapImpl();
        this.OAFRegistry = new DenseIntMapImpl();
        this.LCSFRegistry = new DenseIntMapImpl();
        this.objectAdapterFactories = new HashSet();
        this.objectAdapterFactoriesView = Collections.unmodifiableSet(this.objectAdapterFactories);
        this.stringToServerSubcontract = new HashMap();
    }
    
    public synchronized void registerClientRequestDispatcher(ClientRequestDispatcher clientRequestDispatcher, int n) {
        this.CSRegistry.set(n, clientRequestDispatcher);
    }
    
    public synchronized void registerLocalClientRequestDispatcherFactory(LocalClientRequestDispatcherFactory localClientRequestDispatcherFactory, int n) {
        this.LCSFRegistry.set(n, localClientRequestDispatcherFactory);
    }
    
    public synchronized void registerServerRequestDispatcher(CorbaServerRequestDispatcher corbaServerRequestDispatcher, int n) {
        this.SDRegistry.set(n, corbaServerRequestDispatcher);
    }
    
    public synchronized void registerServerRequestDispatcher(CorbaServerRequestDispatcher corbaServerRequestDispatcher, String s) {
        this.stringToServerSubcontract.put(s, corbaServerRequestDispatcher);
    }
    
    public synchronized void registerObjectAdapterFactory(ObjectAdapterFactory objectAdapterFactory, int n) {
        this.objectAdapterFactories.add(objectAdapterFactory);
        this.OAFRegistry.set(n, objectAdapterFactory);
    }
    
    public CorbaServerRequestDispatcher getServerRequestDispatcher(int n) {
        CorbaServerRequestDispatcher corbaServerRequestDispatcher = (CorbaServerRequestDispatcher)(CorbaServerRequestDispatcher)this.SDRegistry.get(n);
        if (corbaServerRequestDispatcher == null) {
            corbaServerRequestDispatcher = (CorbaServerRequestDispatcher)(CorbaServerRequestDispatcher)this.SDRegistry.get(this.defaultId);
            return corbaServerRequestDispatcher;
        }
        return corbaServerRequestDispatcher;
    }
    
    public CorbaServerRequestDispatcher getServerRequestDispatcher(String s) {
        CorbaServerRequestDispatcher corbaServerRequestDispatcher = (CorbaServerRequestDispatcher)this.stringToServerSubcontract.get(s);
        if (corbaServerRequestDispatcher == null) {
            corbaServerRequestDispatcher = (CorbaServerRequestDispatcher)(CorbaServerRequestDispatcher)this.SDRegistry.get(this.defaultId);
            return corbaServerRequestDispatcher;
        }
        return corbaServerRequestDispatcher;
    }
    
    public LocalClientRequestDispatcherFactory getLocalClientRequestDispatcherFactory(int n) {
        LocalClientRequestDispatcherFactory localClientRequestDispatcherFactory = (LocalClientRequestDispatcherFactory)(LocalClientRequestDispatcherFactory)this.LCSFRegistry.get(n);
        if (localClientRequestDispatcherFactory == null) {
            localClientRequestDispatcherFactory = (LocalClientRequestDispatcherFactory)(LocalClientRequestDispatcherFactory)this.LCSFRegistry.get(this.defaultId);
            return localClientRequestDispatcherFactory;
        }
        return localClientRequestDispatcherFactory;
    }
    
    public ClientRequestDispatcher getClientRequestDispatcher(int n) {
        ClientRequestDispatcher clientRequestDispatcher = (ClientRequestDispatcher)(ClientRequestDispatcher)this.CSRegistry.get(n);
        if (clientRequestDispatcher == null) {
            clientRequestDispatcher = (ClientRequestDispatcher)(ClientRequestDispatcher)this.CSRegistry.get(this.defaultId);
            return clientRequestDispatcher;
        }
        return clientRequestDispatcher;
    }
    
    public ObjectAdapterFactory getObjectAdapterFactory(int n) {
        ObjectAdapterFactory objectAdapterFactory = (ObjectAdapterFactory)(ObjectAdapterFactory)this.OAFRegistry.get(n);
        if (objectAdapterFactory == null) {
            objectAdapterFactory = (ObjectAdapterFactory)(ObjectAdapterFactory)this.OAFRegistry.get(this.defaultId);
            return objectAdapterFactory;
        }
        return objectAdapterFactory;
    }
    
    public Set getObjectAdapterFactories() {
        return this.objectAdapterFactoriesView;
    }
}
